Interface: LineControllerChartOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: LineControllerChartOptions

## # Properties

### # showLine

• showLine: `boolean`

If false, the lines between points are not drawn.

`default` true

#### # Defined in

index.esm.d.ts:216
(opens new window)

### # spanGaps

• spanGaps: `number` | `boolean`

If true, lines will be drawn between points with no or null data. If false, points with NaN data will create a break in the line. Can also be a number specifying the maximum gap length to span. The unit of the value depends on the scale used.

`default` false

#### # Defined in

index.esm.d.ts:211
(opens new window)